@@ -33,13 +33,17 @@ def name_generator(__ctr=[0]):
 @pytest.mark.parametrize("debug", (False, True))
 @pytest.mark.parametrize("cache_timeout", (0,1))
 @pytest.mark.parametrize("sync_rd", (True, False))
-def test_sshfs(tmpdir, debug, cache_timeout, sync_rd, capfd):
+@pytest.mark.parametrize("multiconn", (True,False))
+def test_sshfs(tmpdir, debug, cache_timeout, sync_rd, multiconn, capfd):
     
     # Avoid false positives from debug messages
     #if debug:
     #    capfd.register_output(r'^   unique: [0-9]+, error: -[0-9]+ .+$',
     #                          count=0)
 
+    # Avoid false positives from storing key for localhost 
+    capfd.register_output(r"^Warning: Permanently added 'localhost' .+", count=0)
+    
     # Test if we can ssh into localhost without password
     try:
         res = subprocess.call(['ssh', '-o', 'KbdInteractiveAuthentication=no',
@@ -74,6 +78,8 @@ def test_sshfs(tmpdir, debug, cache_timeout, sync_rd, capfd):
     cmdline += [ '-o', 'entry_timeout=0',
                  '-o', 'attr_timeout=0' ]
 
+    if multiconn:
+        cmdline += [ '-o', 'max_conns=3' ]
     
     new_env = dict(os.environ) # copy, don't modify
 
@@ -109,7 +115,7 @@ def test_sshfs(tmpdir, debug, cache_timeout, sync_rd, capfd):
         tst_truncate_fd(mnt_dir)
         tst_open_unlink(mnt_dir)
     except:
-        cleanup(mnt_dir)
+        cleanup(mount_process, mnt_dir)
         raise
     else:
         umount(mount_process, mnt_dir)
